@@ -4,7 +4,7 @@ to provide special optimized functionality.
 """
 
 from tiddlywebplugins.sqlalchemy import (sRecipe, sPolicy,
-        text_, recipe_policy_table)
+        recipe_policy_table)
 from tiddlywebplugins.mysql import Store as MySQLStore
 from tiddlywebplugins.hashmaker import hash_tiddler
 
@@ -19,10 +19,10 @@ class Store(MySQLStore):
         """
         query = (self.session.query(sRecipe.name)
                 .join((recipe_policy_table,
-                    sRecipe.id==recipe_policy_table.c.recipe_id))
-                .join((sPolicy, recipe_policy_table.c.policy_id==sPolicy.id))
-                .filter(sPolicy.principal_name==username)
-                .filter(sPolicy.constraint=='manage')
+                    sRecipe.id == recipe_policy_table.c.recipe_id))
+                .join((sPolicy, recipe_policy_table.c.policy_id == sPolicy.id))
+                .filter(sPolicy.principal_name == username)
+                .filter(sPolicy.constraint == 'manage')
                 .filter(sRecipe.name.like('%_public')))
         return (name[0] for name in query.all())
 
